# StarWhale Client and Python SDK

# How to develop

- create conda env: `conda create -n starwhale python=3.7`
- install req: `make install-sw`
- install dev-req: `make install-dev-req`
- write some code
- debug starwhale cli: `swcli --help` or some other swcli cmds
- write some code
- run ci: `make all-check`
- submit your pull request
